@@ -12,6 +12,9 @@
 #' If not supplied, it will be calculated by the function
 #' @param signrest A list with vectors containing 1 and -1, e.g. c(1,-1,1), indicating a sign pattern of specific shocks to be tested
 #' with the help of the bootstrap samples.
+#'@param signcheck Boolean. Whether the sign pattern should be checked for each bootstrap iteration.
+#' Note that this procedure is computationally extremely demanding for high dimensional VARs, since the number of possible permutations of B is K!,
+#'  where K is the number of variables in the VAR.
 #' @param itermax Integer. Maximum number of iterations for DEoptim
 #' @param steptol Numeric. Tolerance for steps without improvement for DEoptim
 #' @param iter2 Integer. Number of iterations for the second optimization
@@ -74,7 +77,8 @@
 #' @export
 
 
-mb.boot <- function(x, design = "recursive", b.length = 15, n.ahead = 20, nboot = 500, nc = 1, dd = NULL, signrest = NULL,  itermax = 300, steptol = 200, iter2 = 50){
+mb.boot <- function(x, design = "recursive", b.length = 15, n.ahead = 20, nboot = 500, nc = 1, dd = NULL,
+                    signrest = NULL, signcheck = TRUE,  itermax = 300, steptol = 200, iter2 = 50){
   # x: vars object
   # B: estimated covariance matrix from true data set
   # n.ahead: Time steps for Irf
@@ -202,7 +206,7 @@ mb.boot <- function(x, design = "recursive", b.length = 15, n.ahead = 20, nboot
         } else {
           SB <- x$SB
         }
-        temp <- tryCatch(id.cv_boot(varb, SB = SB, restriction_matrix = x$restriction_matrix),
+        temp <- tryCatch(id.cv_boot(varb, SB = SB, SB2 = x$SB2, restriction_matrix = x$restriction_matrix),
                          error = function(e) NULL)
       }else if(x$method == "Cramer-von Mises distance"){
         temp <- id.cvm(varb, itermax = itermax, steptol = steptol, iter2 = iter2, dd)
@@ -234,7 +238,7 @@ mb.boot <- function(x, design = "recursive", b.length = 15, n.ahead = 20, nboot
       if(x$method == "Non-Gaussian maximum likelihood"){
         temp <- id.ngml_boot(varb, stage3 = x$stage3, Z = Z, restriction_matrix = x$restriction_matrix)
       }else if(x$method == "Changes in Volatility"){
-        temp <- tryCatch(id.cv_boot(varb, SB = x$SB, Z = Z, restriction_matrix = x$restriction_matrix),
+        temp <- tryCatch(id.cv_boot(varb, SB = x$SB, SB2 = x$SB2, Z = Z, restriction_matrix = x$restriction_matrix),
                          error = function(e) NULL)
       }else if(x$method == "Cramer-von Mises distance"){
         temp <- id.cvm(varb, itermax = itermax, steptol = steptol, iter2 = iter2, dd)
@@ -318,62 +322,68 @@ mb.boot <- function(x, design = "recursive", b.length = 15, n.ahead = 20, nboot
   rownames(boot.mean) <- rownames(x$B)
 
   # Checking for signs
-  if(restrictions > 0 | x$method == 'Cholesky'){
-    if(!is.null(signrest)){
-      cat('Testing signs only possible for unrestricted model \n')
+  if (signcheck == TRUE) {
+    if(restrictions > 0 | x$method == 'Cholesky'){
+      if(!is.null(signrest)){
+        cat('Testing signs only possible for unrestricted model \n')
+      }
+      sign.part <- NULL
+      sign.complete <- NULL
+    }else{
+      if(is.null(signrest)){
+        sign.mat <- matrix(FALSE, nrow = k, ncol = k)
+        sign.complete <- 0
+        sign.part <- rep(0, times = k)
+
+        for(i in 1:length(bootstraps)){
+
+          pBs <- permutation(Bs[,,i])
+          sign.mat <-lapply(pBs, function(z){sapply(1:k, function(ii){all(z[,ii]/abs(z[,ii])  == x$B[,ii]/abs(x$B[,ii])) | all(z[,ii]/abs(z[,ii])  == x$B[,ii]/abs(x$B[,ii])*(-1))})})
+
+          if(any(unlist(lapply(sign.mat, function(sign.mat)all(sign.mat == TRUE))))){
+            sign.complete <- sign.complete + 1
+          }
+
+          for(j in 1:k){
+            check <- rep(FALSE, k)
+            for(l in 1:k){
+              check[l] <- any(all(pBs[[1]][,l]/abs(pBs[[1]][,l]) == x$B[,j]/abs(x$B)[,j]) | all(pBs[[1]][,l]/abs(pBs[[1]][,l]) == x$B[,j]/abs(x$B)[,j]*(-1)))
+            }
+            if(sum(check) == 1){
+              sign.part[[j]] <- sign.part[[j]] + 1
+            }
+          }
+        }
+      }else{
+        nrest <- length(signrest)
+        sign.part <- rep(list(0), nrest )
+        sign.complete <- 0
+        for(j in 1:length(bootstraps)){
+          check.full <- 0
+          for(i in 1:nrest){
+            check <- rep(FALSE, length(signrest[[i]][!is.na(signrest[[i]])]))
+            for(l in 1:k){
+              check[l] <- any(all(Bs[!is.na(signrest[[i]]),l,j]/abs(Bs[!is.na(signrest[[i]]),l,j]) == signrest[[i]][!is.na(signrest[[i]])]) |
+                                all(Bs[!is.na(signrest[[i]]),l,j]/abs(Bs[!is.na(signrest[[i]]),l,j]) == signrest[[i]][!is.na(signrest[[i]])]*(-1)))
+            }
+            if(sum(check) == 1){
+              sign.part[[i]] <- sign.part[[i]] + 1
+              check.full <- check.full + 1
+            }
+          }
+          if(check.full == nrest){
+            sign.complete <- sign.complete + 1
+          }
+        }
+        names(sign.part) <- names(signrest)
+      }
     }
+  } else {
     sign.part <- NULL
     sign.complete <- NULL
-  }else{
-    if(is.null(signrest)){
-      sign.mat <- matrix(FALSE, nrow = k, ncol = k)
-      sign.complete <- 0
-      sign.part <- rep(0, times = k)
-
-      for(i in 1:length(bootstraps)){
-
-        pBs <- permutation(Bs[,,i])
-        sign.mat <-lapply(pBs, function(z){sapply(1:k, function(ii){all(z[,ii]/abs(z[,ii])  == x$B[,ii]/abs(x$B[,ii])) | all(z[,ii]/abs(z[,ii])  == x$B[,ii]/abs(x$B[,ii])*(-1))})})
-
-        if(any(unlist(lapply(sign.mat, function(sign.mat)all(sign.mat == TRUE))))){
-          sign.complete <- sign.complete + 1
-        }
-
-        for(j in 1:k){
-          check <- rep(FALSE, k)
-          for(l in 1:k){
-            check[l] <- any(all(pBs[[1]][,l]/abs(pBs[[1]][,l]) == x$B[,j]/abs(x$B)[,j]) | all(pBs[[1]][,l]/abs(pBs[[1]][,l]) == x$B[,j]/abs(x$B)[,j]*(-1)))
-          }
-          if(sum(check) == 1){
-            sign.part[[j]] <- sign.part[[j]] + 1
-          }
-        }
-      }
-    }else{
-      nrest <- length(signrest)
-      sign.part <- rep(list(0), nrest )
-      sign.complete <- 0
-      for(j in 1:length(bootstraps)){
-        check.full <- 0
-        for(i in 1:nrest){
-          check <- rep(FALSE, length(signrest[[i]][!is.na(signrest[[i]])]))
-          for(l in 1:k){
-            check[l] <- any(all(Bs[!is.na(signrest[[i]]),l,j]/abs(Bs[!is.na(signrest[[i]]),l,j]) == signrest[[i]][!is.na(signrest[[i]])]) |
-                              all(Bs[!is.na(signrest[[i]]),l,j]/abs(Bs[!is.na(signrest[[i]]),l,j]) == signrest[[i]][!is.na(signrest[[i]])]*(-1)))
-          }
-          if(sum(check) == 1){
-            sign.part[[i]] <- sign.part[[i]] + 1
-            check.full <- check.full + 1
-          }
-        }
-        if(check.full == nrest){
-          sign.complete <- sign.complete + 1
-        }
-      }
-      names(sign.part) <- names(signrest)
-    }
   }
 
+
   ## Impulse response of actual model
   ip <- irf(x, n.ahead = n.ahead)
 
@@ -395,7 +405,8 @@ mb.boot <- function(x, design = "recursive", b.length = 15, n.ahead = 20, nboot
                  boot_B = Bs,
                  rest_mat = restriction_matrix,
                  method = 'Moving block bootstrap',
-                 VAR = x$VAR)
+                 VAR = x$VAR,
+                 signcheck = signcheck)
   class(result) <- 'sboot'
   return(result)
 }
