@@ -30,7 +30,8 @@
 #' \item{n}{Number of observations}
 #' \item{Fish}{Observed Fisher information matrix}
 #' \item{Lik}{Function value of likelihood}
-#' \item{wald_statistic}{Results of pairwise Wald tests}
+#' \item{wald_statistic}{Results of sequential Wald-type identification test on equal eigenvalues as described in Luetkepohl et. al. (2021).
+#' In case of more than two regimes, pairwise Wald-type tests of equal diagonal elements in the Lambda matrices are performed.}
 #' \item{iteration}{Number of GLS estimations}
 #' \item{method}{Method applied for identification}
 #' \item{SB}{Structural break (number of observations)}
@@ -45,7 +46,10 @@
 #' \item{VAR}{Estimated input VAR object}
 #'
 #' @references Rigobon, R., 2003. Identification through Heteroskedasticity. The Review of Economics and Statistics, 85, 777-792.\cr
-#'  Herwartz, H. & Ploedt, M., 2016. Simulation Evidence on Theory-based and Statistical Identification under Volatility Breaks Oxford Bulletin of Economics and Statistics, 78, 94-112.
+#'
+#'  Herwartz, H. & Ploedt, M., 2016. Simulation Evidence on Theory-based and Statistical Identification under Volatility Breaks. Oxford Bulletin of Economics and Statistics, 78, 94-112.\cr
+#'
+#'  Luetkepohl, H. & Meitz, M. & Netsunajev, A. & and Saikkonen, P.,  2021. Testing identification via heteroskedasticity in structural vector autoregressive models. Econometrics Journal, 24, 1-22.
 #'
 #' @seealso For alternative identification approaches see \code{\link{id.st}}, \code{\link{id.garch}}, \code{\link{id.cvm}}, \code{\link{id.dc}} or \code{\link{id.ngml}}
 #'
@@ -460,9 +464,21 @@ if(is.null(SB2)){
       p = unname(p),                # number of lags
       K = k,# number of time series
       lRatioTest = lRatioTest,
-      AIC = (-2) * best_estimation$Lik + 2*(k + p * k^2 + (k + 1) * k + 1),
       VAR = x
     )
+
+    I_test <- cv_ident_test(result)
+
+    if (type == 'const' | type == 'trend') {
+      result$AIC <- (-2) * result$Lik + 2*(k + p * k^2 + (k + 1) * k + 1)
+    } else if (type == 'none') {
+      result$AIC <- (-2) * result$Lik + 2*(p * k^2 + (k + 1) * k + 1)
+    } else if (type == 'both') {
+      result$AIC <- (-2) * result$Lik + 2*(2*k + p * k^2 + (k + 1) * k + 1)
+    }
+
+    result$wald_statistic <- I_test
+
   } else {
     result <- list(
       Lambda = best_estimation$Lambda,    # estimated Lambda matrix (unconditional heteroscedasticity)
@@ -490,9 +506,15 @@ if(is.null(SB2)){
       p = unname(p),                # number of lags
       K = k,# number of time series
       lRatioTest = lRatioTest,
-      AIC = (-2) * best_estimation$Lik + 2*(k + p * k^2 + (k + 1) * k + 1),
       VAR = x
     )
+    if (type == 'const' | type == 'trend') {
+      result$AIC <- (-2) * result$Lik + 2*(k + p * k^2 + (k + 2) * k + 1)
+    } else if (type == 'none') {
+      result$AIC <- (-2) * result$Lik + 2*(p * k^2 + (k + 2) * k + 1)
+    } else if (type == 'both') {
+      result$AIC <- (-2) * result$Lik + 2*(2*k + p * k^2 + (k + 2) * k + 1)
+    }
   }
   class(result) <- "svars"
  return(result)
