@@ -9,6 +9,7 @@
 #' @param restriction_matrix Matrix. A matrix containing presupposed entries for matrix B, NA if no restriction is imposed (entries to be estimated). Alternatively, a K^2*K^2 matrix can be passed, where ones on the diagonal designate unrestricted and zeros restricted coefficients. (as suggested in Luetkepohl, 2017, section 5.2.1).
 #' @param max.iter Integer. Number of maximum likelihood optimizations
 #' @param crit Numeric. Critical value for the precision of the iterative procedure
+#' @param start_iter Numeric. Number of random candidate initial values for univariate GRACH(1,1) optimization.
 #' @return A list of class "svars" with elements
 #' \item{B}{Estimated structural impact matrix B, i.e. unique decomposition of the covariance matrix of reduced form residuals}
 #' \item{B_SE}{Standard errors of matrix B}
@@ -27,10 +28,14 @@
 #' \item{p}{Number of lags}
 #' \item{K}{Dimension of the VAR}
 #' \item{VAR}{Estimated input VAR object}
+#' \item{I_test}{Results of a series of sequential tests on the number of heteroskedastic shocks present in the system as described in Luetkepohl and Milunovich (2016).}
 #'
 #' @references Normadin, M. & Phaneuf, L., 2004. Monetary Policy Shocks: Testing Identification Conditions under Time-Varying Conditional Volatility. Journal of Monetary Economics, 51(6), 1217-1243.\cr
+#'
 #'  Lanne, M. & Saikkonen, P., 2007. A Multivariate Generalized Orthogonal Factor GARCH Model. Journal of Business & Economic Statistics, 25(1), 61-75.
 #'
+#'  Luetkepohl, H. & Milunovich, G. 2016. Testing for identification in SVAR-GARCH models. Journal of Economic Dynamics and Control, 73(C):241-258
+#'
 #' @seealso For alternative identification approaches see \code{\link{id.st}}, \code{\link{id.cvm}}, \code{\link{id.cv}}, \code{\link{id.dc}} or \code{\link{id.ngml}}
 #'
 #' @examples
@@ -65,7 +70,7 @@
 ## Identification via GARCH ##
 #----------------------------#
 
-id.garch <- function(x, max.iter = 5, crit = 0.001, restriction_matrix = NULL){
+id.garch <- function(x, max.iter = 5, crit = 0.001, restriction_matrix = NULL, start_iter = 50){
 
   u <- Tob <- p <- k <- residY <- coef_x <- yOut <- type <- y <- A_hat <- NULL
   get_var_objects(x)
@@ -99,7 +104,7 @@ id.garch <- function(x, max.iter = 5, crit = 0.001, restriction_matrix = NULL){
   #### Finding optimal starting values ##
   ##***********************************##
 
-  parameter_consider <- GarchStart(k, ste, Tob)
+  parameter_consider <- GarchStart(k, ste, Tob, start_iter)
   parameter_ini_univ <- parameter_consider[[which.min(sapply(parameter_consider, '[[', 'Likelihoods'))]]$ParameterE
 
   Sigma_e_univ <- parameter_consider[[which.min(sapply(parameter_consider, '[[', 'Likelihoods'))]]$ConVariance
@@ -126,8 +131,19 @@ id.garch <- function(x, max.iter = 5, crit = 0.001, restriction_matrix = NULL){
     result <- identifyGARCH(B0 = B0, k = k, Tob = Tob, restriction_matrix = restriction_matrix, Sigma_e_univ = Sigma_e_univ, coef_x = coef_x, x = x,
                             parameter_ini_univ = parameter_ini_univ, max.iter = max.iter, crit = crit, u = u, p = p, yOut = yOut, type = type)
   }
-  result$AIC <- (-2) * result$Lik + 2*(k + p * k^2 + (k + 1) * k + 1)
+  if (type == 'const' | type == 'trend') {
+    result$AIC <- (-2) * result$Lik + 2*(k + p * k^2 + 2*k + k^2)
+  } else if (type == 'none') {
+    result$AIC <- (-2) * result$Lik + 2*(p * k^2 + 2*k + k^2)
+  } else if (type == 'both') {
+    result$AIC <- (-2) * result$Lik + 2*(2*k + p * k^2 + 2*k + k^2)
+  }
+
   result$VAR <- x
+  result$CC <- CC
+
+  result$I_test <- garch_ident_test(result)
+
 
   class(result) <- "svars"
 
